==> haskell-hspec-wai-json-0.9.2-55-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hspec-wai-json.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hspec-wai-json
version: 0.9.2
id: hspec-wai-json-0.9.2-57bg8gkYxSN329hs3FpuI5
key: hspec-wai-json-0.9.2-57bg8gkYxSN329hs3FpuI5
license: MIT
copyright: (c) 2012-2014 Fujimura Daisuke,
           (c) 2014-2018 Simon Hengel
maintainer: Fujimura Daisuke <me@fujimuradaisuke.com>,
            Simon Hengel <sol@typeful.net>
author: Fujimura Daisuke <me@fujimuradaisuke.com>,
        Simon Hengel <sol@typeful.net>
homepage: https://github.com/hspec/hspec-wai#readme
synopsis: Testing JSON APIs with hspec-wai
description:
    Testing JSON APIs with hspec-wai
category: Testing
abi: 8a9b868a700df75fdb0c123961903e30
exposed: True
exposed-modules:
    Test.Hspec.Wai.JSON
hidden-modules: Paths_hspec_wai_json
import-dirs: /usr/lib/ghc-8.6.5/site-local/hspec-wai-json-0.9.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/hspec-wai-json-0.9.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/hspec-wai-json-0.9.2
hs-libraries: HShspec-wai-json-0.9.2-57bg8gkYxSN329hs3FpuI5
depends:
    aeson-1.4.4.0-7vLg8fT3jLZEAAmFwxYKHF
    aeson-qq-0.8.2-5C1qaizIEmQD0NVna2QZtT base-4.12.0.0
    bytestring-0.10.8.2 case-insensitive-1.2.1.0-L7BR5PaOPZy5cAHpLYQKhk
    hspec-wai-0.9.2-2dEdtb6NaVG6mbvtz9L8c9 template-haskell-2.14.0.0
haddock-interfaces: /usr/share/doc/haskell-hspec-wai-json/html/hspec-wai-json.haddock
haddock-html: /usr/share/doc/haskell-hspec-wai-json/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-wai-json-0.9.2-56-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hspec-wai-json.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hspec-wai-json
version: 0.9.2
id: hspec-wai-json-0.9.2-767BfX6JoXyAO5vzKNBtJJ
key: hspec-wai-json-0.9.2-767BfX6JoXyAO5vzKNBtJJ
license: MIT
copyright: (c) 2012-2014 Fujimura Daisuke,
           (c) 2014-2018 Simon Hengel
maintainer: Fujimura Daisuke <me@fujimuradaisuke.com>,
            Simon Hengel <sol@typeful.net>
author: Fujimura Daisuke <me@fujimuradaisuke.com>,
        Simon Hengel <sol@typeful.net>
homepage: https://github.com/hspec/hspec-wai#readme
synopsis: Testing JSON APIs with hspec-wai
description:
    Testing JSON APIs with hspec-wai
category: Testing
abi: 4db2485180f0b88453a4afedc3907a3d
exposed: True
exposed-modules:
    Test.Hspec.Wai.JSON
hidden-modules: Paths_hspec_wai_json
import-dirs: /usr/lib/ghc-8.6.5/site-local/hspec-wai-json-0.9.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/hspec-wai-json-0.9.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/hspec-wai-json-0.9.2
hs-libraries: HShspec-wai-json-0.9.2-767BfX6JoXyAO5vzKNBtJJ
depends:
    aeson-1.4.4.0-7vLg8fT3jLZEAAmFwxYKHF
    aeson-qq-0.8.2-5C1qaizIEmQD0NVna2QZtT base-4.12.0.0
    bytestring-0.10.8.2 case-insensitive-1.2.1.0-L7BR5PaOPZy5cAHpLYQKhk
    hspec-wai-0.9.2-IK4F0HJb6qaEFLdQ5oDR76 template-haskell-2.14.0.0
haddock-interfaces: /usr/share/doc/haskell-hspec-wai-json/html/hspec-wai-json.haddock
haddock-html: /usr/share/doc/haskell-hspec-wai-json/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
